@@ -244,33 +244,65 @@ enum ExceptionCause Core::memory_special(
         towrite_val = mem_data->read_u32(mem_addr);
         break;
     case AC_WORD_RIGHT:
-        if (memwrite) {
-            shift = (3u - (mem_addr.get_raw() & 3u)) << 3;
-            mask = 0xffffffff << shift;
-            temp = mem_data->read_u32(mem_addr & ~3u);
-            temp = (temp & ~mask) | (rt_value.as_u32() << shift);
-            mem_data->write_u32(mem_addr & ~3u, temp);
+        if (mem_data->simulated_machine_endian == LITTLE) {
+            if (memwrite) {
+                shift = (mem_addr.get_raw() & 3u) << 3;
+                mask = 0xffffffff << shift;
+                temp = mem_data->read_u32(mem_addr & ~3u);
+                temp = (temp & ~mask) | (rt_value.as_u32() << shift);
+                mem_data->write_u32(mem_addr & ~3u, temp);
+            } else {
+                shift = (mem_addr.get_raw() & 3u) << 3;
+                mask = 0xffffffff >> shift;
+                towrite_val = mem_data->read_u32(mem_addr & ~3u);
+                towrite_val
+                    = (towrite_val.as_u32() >> shift) | (rt_value.as_u32() & ~mask);
+            }
         } else {
-            shift = (3u - (mem_addr.get_raw() & 3u)) << 3;
-            mask = 0xffffffff >> shift;
-            towrite_val = mem_data->read_u32(mem_addr & ~3u);
-            towrite_val
-                = (towrite_val.as_u32() >> shift) | (rt_value.as_u32() & ~mask);
+            if (memwrite) {
+                shift = (3u - (mem_addr.get_raw() & 3u)) << 3;
+                mask = 0xffffffff << shift;
+                temp = mem_data->read_u32(mem_addr & ~3u);
+                temp = (temp & ~mask) | (rt_value.as_u32() << shift);
+                mem_data->write_u32(mem_addr & ~3u, temp);
+            } else {
+                shift = (3u - (mem_addr.get_raw() & 3u)) << 3;
+                mask = 0xffffffff >> shift;
+                towrite_val = mem_data->read_u32(mem_addr & ~3u);
+                towrite_val
+                    = (towrite_val.as_u32() >> shift) | (rt_value.as_u32() & ~mask);
+            }
         }
         break;
     case AC_WORD_LEFT:
-        if (memwrite) {
-            shift = (mem_addr.get_raw() & 3u) << 3;
-            mask = 0xffffffff >> shift;
-            temp = mem_data->read_u32(mem_addr & ~3);
-            temp = (temp & ~mask) | (rt_value.as_u32() >> shift);
-            mem_data->write_u32(mem_addr & ~3, temp);
+        if (mem_data->simulated_machine_endian == LITTLE) {
+            if (memwrite) {
+                shift = (3u - (mem_addr.get_raw() & 3u)) << 3;
+                mask = 0xffffffff >> shift;
+                temp = mem_data->read_u32(mem_addr & ~3);
+                temp = (temp & ~mask) | (rt_value.as_u32() >> shift);
+                mem_data->write_u32(mem_addr & ~3, temp);
+            } else {
+                shift = (3u - (mem_addr.get_raw() & 3u)) << 3;
+                mask = 0xffffffff << shift;
+                towrite_val = mem_data->read_u32(mem_addr & ~3);
+                towrite_val
+                    = (towrite_val.as_u32() << shift) | (rt_value.as_u32() & ~mask);
+            }
         } else {
-            shift = (mem_addr.get_raw() & 3u) << 3;
-            mask = 0xffffffff << shift;
-            towrite_val = mem_data->read_u32(mem_addr & ~3);
-            towrite_val
-                = (towrite_val.as_u32() << shift) | (rt_value.as_u32() & ~mask);
+            if (memwrite) {
+                shift = (mem_addr.get_raw() & 3u) << 3;
+                mask = 0xffffffff >> shift;
+                temp = mem_data->read_u32(mem_addr & ~3);
+                temp = (temp & ~mask) | (rt_value.as_u32() >> shift);
+                mem_data->write_u32(mem_addr & ~3, temp);
+            } else {
+                shift = (mem_addr.get_raw() & 3u) << 3;
+                mask = 0xffffffff << shift;
+                towrite_val = mem_data->read_u32(mem_addr & ~3);
+                towrite_val
+                    = (towrite_val.as_u32() << shift) | (rt_value.as_u32() & ~mask);
+            }
         }
         break;
     default: break;
